@@ -1,6 +1,5 @@
 """
-GUI progressbar decorator for iterators.
-Includes a default `range` iterator printing to `stderr`.
+Matplotlib GUI progressbar decorator for iterators.
 
 Usage:
 >>> from tqdm.gui import trange, tqdm
@@ -9,39 +8,36 @@ Usage:
 """
 # future division is important to divide integers and get as
 # a result precise floating numbers (instead of truncated int)
-from __future__ import division, absolute_import
-# import compatibility functions and utilities
-from .utils import _range
-# to inherit from the tqdm class
-from .std import tqdm as std_tqdm
-from .std import TqdmExperimentalWarning
+import re
 from warnings import warn
 
+# to inherit from the tqdm class
+from .std import TqdmExperimentalWarning
+from .std import tqdm as std_tqdm
+
+# import compatibility functions and utilities
+
 __author__ = {"github.com/": ["casperdcl", "lrq3000"]}
 __all__ = ['tqdm_gui', 'tgrange', 'tqdm', 'trange']
 
 
 class tqdm_gui(std_tqdm):  # pragma: no cover
-    """
-    Experimental GUI version of tqdm!
-    """
-
+    """Experimental Matplotlib GUI version of tqdm!"""
     # TODO: @classmethod: write() on GUI?
-
     def __init__(self, *args, **kwargs):
+        from collections import deque
+
         import matplotlib as mpl
         import matplotlib.pyplot as plt
-        from collections import deque
         kwargs = kwargs.copy()
         kwargs['gui'] = True
         colour = kwargs.pop('colour', 'g')
         super(tqdm_gui, self).__init__(*args, **kwargs)
 
-        # Initialize the GUI display
-        if self.disable or not kwargs['gui']:
+        if self.disable:
             return
 
-        warn('GUI is experimental/alpha', TqdmExperimentalWarning, stacklevel=2)
+        warn("GUI is experimental/alpha", TqdmExperimentalWarning, stacklevel=2)
         self.mpl = mpl
         self.plt = plt
 
@@ -66,8 +62,8 @@ class tqdm_gui(std_tqdm):  # pragma: no cover
         ax.set_ylim(0, 0.001)
         if total is not None:
             ax.set_xlim(0, 100)
-            ax.set_xlabel('percent')
-            self.fig.legend((self.line1, self.line2), ('cur', 'est'),
+            ax.set_xlabel("percent")
+            self.fig.legend((self.line1, self.line2), ("cur", "est"),
                             loc='center right')
             # progressbar
             self.hspan = plt.axhspan(0, 0.001, xmin=0, xmax=0, color=colour)
@@ -75,11 +71,11 @@ class tqdm_gui(std_tqdm):  # pragma: no cover
             # ax.set_xlim(-60, 0)
             ax.set_xlim(0, 60)
             ax.invert_xaxis()
-            ax.set_xlabel('seconds')
-            ax.legend(('cur', 'est'), loc='lower left')
+            ax.set_xlabel("seconds")
+            ax.legend(("cur", "est"), loc='lower left')
         ax.grid()
         # ax.set_xlabel('seconds')
-        ax.set_ylabel((self.unit if self.unit else 'it') + '/s')
+        ax.set_ylabel((self.unit if self.unit else "it") + "/s")
         if self.unit_scale:
             plt.ticklabel_format(style='sci', axis='y', scilimits=(0, 0))
             ax.yaxis.get_offset_text().set_x(-0.15)
@@ -90,8 +86,6 @@ class tqdm_gui(std_tqdm):  # pragma: no cover
         self.ax = ax
 
     def close(self):
-        # if not self.gui:
-        #   return super(tqdm_gui, self).close()
         if self.disable:
             return
 
@@ -113,7 +107,7 @@ class tqdm_gui(std_tqdm):  # pragma: no cover
     def clear(self, *_, **__):
         pass
 
-    def display(self):
+    def display(self, *_, **__):
         n = self.n
         cur_t = self._time()
         elapsed = cur_t - self.start_t
@@ -172,17 +166,19 @@ class tqdm_gui(std_tqdm):  # pragma: no cover
             line2.set_data(t_ago, zdata)
 
         d = self.format_dict
-        d["ncols"] = 0
-        ax.set_title(self.format_meter(**d), fontname="DejaVu Sans Mono", fontsize=11)
+        # remove {bar}
+        d['bar_format'] = (d['bar_format'] or "{l_bar}<bar/>{r_bar}").replace(
+            "{bar}", "<bar/>")
+        msg = self.format_meter(**d)
+        if '<bar/>' in msg:
+            msg = "".join(re.split(r'\|?<bar/>\|?', msg, 1))
+        ax.set_title(msg, fontname="DejaVu Sans Mono", fontsize=11)
         self.plt.pause(1e-9)
 
 
 def tgrange(*args, **kwargs):
-    """
-    A shortcut for `tqdm.gui.tqdm(xrange(*args), **kwargs)`.
-    On Python3+, `range` is used instead of `xrange`.
-    """
-    return tqdm_gui(_range(*args), **kwargs)
+    """Shortcut for `tqdm.gui.tqdm(range(*args), **kwargs)`."""
+    return tqdm_gui(range(*args), **kwargs)
 
 
 # Aliases
